- deprecate-find_task_by_pid-kgdb.patch removed from -mm tree

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The patch titled
     Deprecate find_task_by_pid(): kgdb
has been removed from the -mm tree.  Its filename was
     deprecate-find_task_by_pid-kgdb.patch

This patch was dropped because I dropped git-x86

The current -mm tree may be found at http://userweb.kernel.org/~akpm/mmotm/

------------------------------------------------------
Subject: Deprecate find_task_by_pid(): kgdb
From: Pavel Emelyanov <xemul@xxxxxxxxxx>

There are some places that are known to operate on tasks'
global pids only:

* the rest_init() call (called on boot)
* the kgdb's getthread
* the create_kthread() (since the kthread is run in init ns)

So use the find_task_by_pid_ns(..., &init_pid_ns) there
and schedule the find_task_by_pid for removal.

Signed-off-by: Pavel Emelyanov <xemul@xxxxxxxxxx>
Cc: "Eric W. Biederman" <ebiederm@xxxxxxxxxxxx>
Cc: Ingo Molnar <mingo@xxxxxxx>
Cc: Thomas Gleixner <tglx@xxxxxxxxxxxxx>
Signed-off-by: Andrew Morton <akpm@xxxxxxxxxxxxxxxxxxxx>
---

 kernel/kgdb.c |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff -puN kernel/kgdb.c~deprecate-find_task_by_pid-kgdb kernel/kgdb.c
--- a/kernel/kgdb.c~deprecate-find_task_by_pid-kgdb
+++ a/kernel/kgdb.c
@@ -720,11 +720,11 @@ static struct task_struct *getthread(str
 		return NULL;
 
 	/*
 	 * find_task_by_pid() does not take the tasklist lock anymore
 	 * but is nicely RCU locked - hence is a pretty resilient
 	 * thing to use:
 	 */
-	return find_task_by_pid(tid);
+	return find_task_by_pid_ns(tid, &init_pid_ns);
 }
 #ifdef CONFIG_DETECT_SOFTLOCKUP
 static int kgdb_softlock_reset[NR_CPUS];
_

Patches currently in -mm which might be from xemul@xxxxxxxxxx are

use-find_task_by_vpid-in-audit-code.patch
ia64-fix-ptrace-inside-a-namespace.patch
mips-use-find_task_by_vpid-in-system-calls.patch
git-net.patch
usbatm-switch-to-kthread-api-stop-using-kill_proc.patch
deprecate-find_task_by_pid-kgdb.patch
remove-unused-variable-from-send_signal.patch
turn-legacy_queue-macro-into-static-inline-function.patch
consolidate-checking-for-ignored-legacy-signals.patch
consolidate-checking-for-ignored-legacy-signals-simplify.patch
use-find_task_by_vpid-in-taskstats.patch
deprecate-find_task_by_pid.patch
reiser4.patch

-
@@ -720,11 +720,11 @@ static struct task_struct *getthread(str
 
 	/*
-	 * find_task_by_pid() does not take the tasklist lock anymore
+	 * find_task_by_pid_ns() does not take the tasklist lock anymore
 	 * but is nicely RCU locked - hence is a pretty resilient
 	 * thing to use:
To unsubscribe from this list: send the line "unsubscribe mm-commits" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Kernel Newbies FAQ]     [Kernel Archive]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [Bugtraq]     [Photo]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]

  Powered by Linux